@@ -43,7 +43,7 @@ Tensor <- R7Class(
       invisible(self)
     },
     dim = function() {
-      length(self$size())
+      cpp_tensor_ndim(self)
     },
     size = function(dim) {
       x <- cpp_tensor_dim(self$ptr)
@@ -250,6 +250,15 @@ Tensor <- R7Class(
     },
     view = function(size) {
       private$`_view`(size = size)
+    },
+    bincount = function(weights = list(), minlength = 0L) {
+      to_index_tensor(self)$private$`_bincount`(weights = weights, minlength = minlength)
+    },
+    is_sparse = function() {
+      cpp_method_Tensor_is_sparse(self)
+    },
+    movedim = function(source, destination) {
+      private$`_movedim`(as_1_based_dim(source), as_1_based_dim(destination))
     }
   ),
   active = list(
