@@ -290,6 +290,11 @@ std::vector<int> cpp_tensor_dim(Rcpp::XPtr<torch::Tensor> x) {
   return out;
 }
 
+// [[Rcpp::export]]
+int cpp_tensor_ndim (torch::Tensor x) {
+  return lantern_Tensor_ndimension(x.get());
+}
+
 // [[Rcpp::export]]
 int cpp_tensor_numel(Rcpp::XPtr<torch::Tensor> x) {
   return lantern_Tensor_numel(x->get());
@@ -381,3 +386,8 @@ torch::Tensor nnf_pad_circular(torch::Tensor input,
   return torch::Tensor(
       lantern_nn_functional_pad_circular(input.get(), padding.get()));
 }
+
+// [[Rcpp::export]]
+bool cpp_method_Tensor_is_sparse (torch::Tensor x) {
+  return lantern_Tensor_is_sparse(x.get());
+}
